How do I ...?
=============

Flax `builds on top of JAX's purely function semantics <design_notes/linen_design_principles.html>`__, thus
some patterns for using Flax may require some getting used to.
Ultimately, the goal is to make things explicit, flexible, and
directly interoperable with JAX.

Please open a `discussion <https://github.com/google/flax/discussions/new>`__ if you have a "how do I ...?" question
that's not answered here.

.. toctree::
   :maxdepth: 0
   :glob:
   :titlesonly:

   howtos/*
